View Source Stripe.Issuing.Cardholder (Striped v0.1.0)

An Issuing Cardholder object represents an individual or business entity who is issued cards.

Related guide: How to create a Cardholder

Link to this section Summary

Types

t()

The issuing.cardholder type.

Functions

Creates a new Issuing Cardholder object that can be issued cards.

Returns a list of Issuing Cardholder objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.

Retrieves an Issuing Cardholder object.

Updates the specified Issuing Cardholder object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.

Link to this section Types

@type t() :: %Stripe.Issuing.Cardholder{
  billing: term(),
  company: term() | nil,
  created: integer(),
  email: binary() | nil,
  id: binary(),
  individual: term() | nil,
  livemode: boolean(),
  metadata: term(),
  name: binary(),
  object: binary(),
  phone_number: binary() | nil,
  requirements: term(),
  spending_controls: term() | nil,
  status: binary(),
  type: binary()
}

The issuing.cardholder type.

  • billing
  • company Additional information about a company cardholder.
  • created Time at which the object was created. Measured in seconds since the Unix epoch.
  • email The cardholder's email address.
  • id Unique identifier for the object.
  • individual Additional information about an individual cardholder.
  • livemode Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • metadata Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
  • name The cardholder's name. This will be printed on cards issued to them.
  • object String representing the object's type. Objects of the same type share the same value.
  • phone_number The cardholder's phone number. This is required for all cardholders who will be creating EU cards. See the 3D Secure documentation for more details.
  • requirements
  • spending_controls Rules that control spending across this cardholder's cards. Refer to our documentation for more details.
  • status Specifies whether to permit authorizations on this cardholder's cards.
  • type One of individual or company.

Link to this section Functions

Link to this function

create(client, params \\ %{})

@spec create(client :: term(), params :: map()) ::
  {:ok, t()} | {:error, Stripe.ApiErrors.t()} | {:error, term()}

Creates a new Issuing Cardholder object that can be issued cards.

Details

  • Method: post
  • Path: /v1/issuing/cardholders
Link to this function

list(client, params \\ %{})

@spec list(client :: term(), params :: map()) ::
  {:ok, Stripe.List.t(t())} | {:error, Stripe.ApiErrors.t()} | {:error, term()}

Returns a list of Issuing Cardholder objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.

Details

  • Method: get
  • Path: /v1/issuing/cardholders

Query parameters

  • :created any of:
    • object with (optional) properties:
      • gt: integer
      • gte: integer
      • lt: integer
      • lte: integer
    • integer
  • :email string
  • :ending_before string
  • :expand array of: string
  • :limit integer
  • :phone_number string
  • :starting_after string
  • :status string
  • :type string
Link to this function

retrieve(client, cardholder, params \\ %{})

@spec retrieve(client :: term(), cardholder :: binary(), params :: map()) ::
  {:ok, t()} | {:error, Stripe.ApiErrors.t()} | {:error, term()}

Retrieves an Issuing Cardholder object.

Details

  • Method: get
  • Path: /v1/issuing/cardholders/{cardholder}

Query parameters

  • :expand array of: string
Link to this function

update(client, cardholder, params \\ %{})

@spec update(client :: term(), cardholder :: binary(), params :: map()) ::
  {:ok, t()} | {:error, Stripe.ApiErrors.t()} | {:error, term()}

Updates the specified Issuing Cardholder object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.

Details

  • Method: post
  • Path: /v1/issuing/cardholders/{cardholder}