View Source Stripe.Issuing.Cardholder (Striped v0.1.0)
An Issuing Cardholder object represents an individual or business entity who is issued cards.
Related guide: How to create a Cardholder
Link to this section Summary
Functions
Creates a new Issuing Cardholder object that can be issued cards.
Returns a list of Issuing Cardholder objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
Retrieves an Issuing Cardholder object.
Updates the specified Issuing Cardholder object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
Link to this section Types
@type t() :: %Stripe.Issuing.Cardholder{ billing: term(), company: term() | nil, created: integer(), email: binary() | nil, id: binary(), individual: term() | nil, livemode: boolean(), metadata: term(), name: binary(), object: binary(), phone_number: binary() | nil, requirements: term(), spending_controls: term() | nil, status: binary(), type: binary() }
The issuing.cardholder type.
billingcompanyAdditional information about acompanycardholder.createdTime at which the object was created. Measured in seconds since the Unix epoch.emailThe cardholder's email address.idUnique identifier for the object.individualAdditional information about anindividualcardholder.livemodeHas the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.metadataSet of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.nameThe cardholder's name. This will be printed on cards issued to them.objectString representing the object's type. Objects of the same type share the same value.phone_numberThe cardholder's phone number. This is required for all cardholders who will be creating EU cards. See the 3D Secure documentation for more details.requirementsspending_controlsRules that control spending across this cardholder's cards. Refer to our documentation for more details.statusSpecifies whether to permit authorizations on this cardholder's cards.typeOne ofindividualorcompany.
Link to this section Functions
@spec create(client :: term(), params :: map()) :: {:ok, t()} | {:error, Stripe.ApiErrors.t()} | {:error, term()}
Creates a new Issuing Cardholder object that can be issued cards.
Details
- Method:
post - Path:
/v1/issuing/cardholders
@spec list(client :: term(), params :: map()) :: {:ok, Stripe.List.t(t())} | {:error, Stripe.ApiErrors.t()} | {:error, term()}
Returns a list of Issuing Cardholder objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
Details
- Method:
get - Path:
/v1/issuing/cardholders
Query parameters
:createdany of:- object with (optional) properties:
gt: integergte: integerlt: integerlte: integer
- integer
- object with (optional) properties:
:emailstring:ending_beforestring:expandarray of: string:limitinteger:phone_numberstring:starting_afterstring:statusstring:typestring
@spec retrieve(client :: term(), cardholder :: binary(), params :: map()) :: {:ok, t()} | {:error, Stripe.ApiErrors.t()} | {:error, term()}
Retrieves an Issuing Cardholder object.
Details
- Method:
get - Path:
/v1/issuing/cardholders/{cardholder}
Query parameters
:expandarray of: string
@spec update(client :: term(), cardholder :: binary(), params :: map()) :: {:ok, t()} | {:error, Stripe.ApiErrors.t()} | {:error, term()}
Updates the specified Issuing Cardholder object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
Details
- Method:
post - Path:
/v1/issuing/cardholders/{cardholder}